@@ -11,12 +11,7 @@ from helpers import allclose, eik2d
         ([0.0, 0.0], [-1.0, -1.0], numpy.nan, numpy.nan),
         (
             [0.0, 0.0],
-            [
-                [0.0, 0.0],
-                [15.0, 0.0],
-                [15.0, 15.0],
-                [0.0, 15.0],
-            ],
+            [[0.0, 0.0], [15.0, 0.0], [15.0, 15.0], [0.0, 15.0],],
             [0.0, 1.0, 0.69457650, 0.0],
             [0.0, 0.0, 0.69457650, 1.0],
         ),
